@@ -1,9 +1,8 @@
-// Copyright 2018-2020 Camilo Higuita <milo.h@aol.com>
-// Copyright 2018-2020 Nitrux Latinoamericana S.C.
+// Copyright 2018-2023 Camilo Higuita <milo.h@aol.com>
+// Copyright 2018-2023 Nitrux Latinoamericana S.C.
 //
 // SPDX-License-Identifier: GPL-3.0-or-later
 #include <QCommandLineParser>
-#include <QDate>
 #include <QIcon>
 #include <QQmlApplicationEngine>
 #include <QQmlContext>
@@ -21,7 +20,9 @@
 #endif
 
 #include <MauiKit3/Core/mauiapp.h>
+#include <MauiKit3/FileBrowsing/moduleinfo.h>
 
+#include <KIO/kio_version.h>
 #include <KAboutData>
 #include <KI18n/KLocalizedString>
 
@@ -63,8 +64,13 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
 
     KLocalizedString::setApplicationDomain("index-fm");
 
-    KAboutData about(QStringLiteral("index"), i18n("Index"), INDEX_VERSION_STRING, i18n("Browse, organize and preview your files."),
-                     KAboutLicense::LGPL_V3, i18n("© 2019-%1 Maui Development Team", QString::number(QDate::currentDate().year())), QString(GIT_BRANCH) + "/" + QString(GIT_COMMIT_HASH));
+    KAboutData about(QStringLiteral("index"),
+                     i18n("Index"),
+                     INDEX_VERSION_STRING,
+                     i18n("Browse, organize and preview your files."),
+                     KAboutLicense::LGPL_V3,
+                     i18n("© 2019-2023 Maui Development Team"),
+                     QString(GIT_BRANCH) + "/" + QString(GIT_COMMIT_HASH));
 
     about.addAuthor(i18n("Camilo Higuita"), i18n("Developer"), QStringLiteral("milo.h@aol.com"));
     about.addAuthor(i18n("Gabriel Dominguez"), i18n("Developer"), QStringLiteral("gabriel@gabrieldominguez.es"));
@@ -73,7 +79,10 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
     about.setBugAddress("https://invent.kde.org/maui/index-fm/-/issues");
     about.setOrganizationDomain(INDEX_URI);
     about.setProgramLogo(app.windowIcon());
-    about.addComponent("KIO");
+    about.addComponent("KIO", "", KIO_VERSION_STRING);
+
+    const auto FBData = MauiKitFileBrowsing::aboutData();
+    about.addComponent(FBData.name(), MauiKitFileBrowsing::buildVersion(), FBData.version(), FBData.webAddress());
 
     KAboutData::setApplicationData(about);
     MauiApp::instance()->setIconName("qrc:/assets/index.png");
